/********************************************************************
* jquery.boxscroll.js
*
* @desc         This script enabales you to make the site that
*               target box of side part follows window scroll.
*
* @author		Shigeru Kuratani <kuratani@benefiss.com>
* @copyright	2012, Shigeru Kuratani <Kuratani@benefiss.com>
* @license		Creative Commons License
* @version		1.0.0
* @link			http://bs.benefiss.com
* @since		File available since Release 1.0.0
********************************************************************/

/**
 * boxScroll definition
 */
$.fn.boxScroll = function(parentNodeId, nodeId, topMargin){
	
	boxScrollObj = {};
	boxScrollObj.parentNodeId = parentNodeId;
	boxScrollObj.nodeId = nodeId;
	boxScrollObj.marginTop = topMargin;
	
	this.constructor = setScrollMotion(parentNodeId, nodeId); // constructor
}

/**
 * boxScroll constructor
 *
 * @param string parentNodeId  ID of parent element
 * @param string nodeId  ID of target element
 * @return void
 */
function setScrollMotion(parentNodeId, nodeId) {
	/*
	 * 1．initialize
	 * 2．initial scroll
	 * 3．set of timer
	 */
	$(document).ready(function(){
		$('#' + boxScrollObj.parentNodeId).css('position', 'relative');
		$('#' + boxScrollObj.nodeId).css('position', 'absolute');
		
		// initial scroll
		//setScrollFunction(boxScrollObj.nodeId, boxScrollObj.marginTop);
		
		// set timer 
		window.setInterval('scrollMotion()', 1000);
	});
}

/**
 * function of setting to window object
 *
 * @param void
 * @return void
 */
function scrollMotion() {
	var windowScrollTop = document.documentElement.scrollTop || document.body.scrollTop; // amount of window scroll
	var parentNodeOffsetTop = $('#' + boxScrollObj.parentNodeId).offset().top; // offset of parent element
	var nodeOffsetTop = $('#' + boxScrollObj.nodeId).offset().top - parentNodeOffsetTop; // offset of target element
	if (windowScrollTop > parentNodeOffsetTop) {
		if (Math.abs((windowScrollTop + boxScrollObj.marginTop) - (parentNodeOffsetTop + nodeOffsetTop)) > 1) {
			setScrollFunction(boxScrollObj.nodeId, getScrollMeasure());
		}
	} else {
		if (nodeOffsetTop > boxScrollObj.marginTop) {
			setScrollFunction(boxScrollObj.nodeId, -nodeOffsetTop);
		}
	}
}

/**
 * scroll prosess of target element
 *
 * @param string nodeId  ID of target element
 * @param number scrollAmount  amount of scroll(px)
 * @return void
 */
function setScrollFunction(nodeId, scrollAmount) {
	var parentNodeOffsetTop = $('#' + boxScrollObj.parentNodeId).offset().top; // offset of parent element
	var nodeOffsetTop = $('#' + boxScrollObj.nodeId).offset().top - parentNodeOffsetTop; // offset of target element

	$('#' + nodeId).animate(
		{top : (nodeOffsetTop + scrollAmount) + 'px'},
		"slow"
	);
}

/**
 * calculate amount of scroll
 *
 * @param void
 * @return number scrollMeasure  amount of scroll
 */
function getScrollMeasure() {
	var windowScrollTop = document.documentElement.scrollTop || document.body.scrollTop; // amount of window scroll
	var parentNodeOffsetTop = $('#' + boxScrollObj.parentNodeId).offset().top; // offset of parent element
	var nodeOffsetTop = $('#' + boxScrollObj.nodeId).offset().top - parentNodeOffsetTop; // offset of target element
	
	if (windowScrollTop + boxScrollObj.marginTop != parentNodeOffsetTop + nodeOffsetTop) {
		var scrollMeasure = (windowScrollTop + boxScrollObj.marginTop) - (parentNodeOffsetTop + nodeOffsetTop);
	} else {
		var scrollMeasure = 0;
	}
	
	return scrollMeasure;
}
